@@ -1,11 +1,15 @@
 """Task to publish msgs to GCP Pub/Sub topic."""
 
-from blackcap import celery_app
-from blackcap.extensions import messenger
+from blackcap.configs import config_registry
+from blackcap.messenger import messenger_registry
 from blackcap.schemas.message import Message
+from blackcap.workers import celery_app
 
 from logzero import logger
 
+config = config_registry.get_config()
+messenger = messenger_registry.get_messenger(config.MESSENGER)
+
 
 @celery_app.task
 def publish_messenger(msg: Message, topic_id: str) -> None:
